summaryrefslogtreecommitdiffstatshomepage
path: root/src/tools
diff options
context:
space:
mode:
author Miodrag Milanovic <mmicko@gmail.com>2014-04-16 08:04:20 +0000
committer Miodrag Milanovic <mmicko@gmail.com>2014-04-16 08:04:20 +0000
commit67663501d7a646a5d4f43fc9c054d99bf3ce2544 (patch)
tree49beebd42271006da0c177515ecbf1f31a31b079 /src/tools
parent72d93bb509f7ba670c27850f58fe10ce09844a93 (diff)
Moved eminline and related files into /src/osd since it's system related (nw)
Moved delegates into /src/lib/util to enable usage of delegates in other project parts Moved mame_printf_* calls into /src/osd/osdcore.c and renamed them to osd_printf_* Changed mess.mak to display compilation of ymmu100.ppm nicely
Diffstat (limited to 'src/tools')
-rw-r--r--src/tools/nltool.c2
-rw-r--r--src/tools/unidasm.c4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/tools/nltool.c b/src/tools/nltool.c
index 2a3e68339da..e1198160964 100644
--- a/src/tools/nltool.c
+++ b/src/tools/nltool.c
@@ -25,7 +25,7 @@
***************************************************************************/
#if 0
-void ATTR_PRINTF(1,2) mame_printf_warning(const char *format, ...)
+void ATTR_PRINTF(1,2) osd_printf_warning(const char *format, ...)
{
va_list argptr;
diff --git a/src/tools/unidasm.c b/src/tools/unidasm.c
index ffb6ceaa84f..6b03c2d7cad 100644
--- a/src/tools/unidasm.c
+++ b/src/tools/unidasm.c
@@ -349,9 +349,9 @@ void CLIB_DECL ATTR_PRINTF(1,2) logerror(const char *format, ...)
}
-void CLIB_DECL ATTR_PRINTF(1,2) mame_printf_debug(const char *format, ...)
+void CLIB_DECL ATTR_PRINTF(1,2) osd_printf_debug(const char *format, ...)
{
/* silent mame_printf_debugs are allowed in disassemblers */
}
@@ -349,9 +349,9 @@ void CLIB_DECL ATTR_PRINTF(1,2) logerror(const char *format, ...)
{
- /* silent mame_printf_debugs are allowed in disassemblers */
+ /* silent osd_printf_debugs are allowed in disassemblers */
}